@@ -71,7 +71,7 @@ signalHsmm_decision <- function(prot, aa_group, pipar, tpmpar,
   #get probabilities of no signal peptide model
   prob.non <- Reduce(function(x, y) x + overall_probs_log[y], deg_sample[1L:c_site], 0)
   prob.total <- exp(prob.signal - prob.non)
-  res <- list(sp_probability = rescale(unname(1 - 1/(1 + prob.total))),
+  res <- list(sp_probability = unname(1 - 1/(1 + prob.total)),
               sp_start = 1,
               sp_end = c_site,
               struc = viterbi_path,
